@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2009 Pierre-Luc Beaudoin <pierre-luc@pierlux.com>
+ * Copyright (C) 2010 Jiri Techet <techet@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -40,7 +41,7 @@
 
 #include "champlain.h"
 #ifdef CHAMPLAIN_HAS_MEMPHIS
-#include "champlain-memphis.h"
+#include "champlain-memphis-renderer.h"
 #endif
 #include "champlain-file-cache.h"
 #include "champlain-defines.h"
@@ -50,7 +51,9 @@
 #include "champlain-private.h"
 #include "champlain-network-tile-source.h"
 #include "champlain-map-source-chain.h"
-#include "champlain-error-tile-source.h"
+#include "champlain-error-tile-renderer.h"
+#include "champlain-image-renderer.h"
+#include "champlain-file-tile-source.h"
 
 #include <glib.h>
 #include <string.h>
@@ -71,52 +74,24 @@ static ChamplainMapSourceFactory *instance = NULL;
 
 G_DEFINE_TYPE (ChamplainMapSourceFactory, champlain_map_source_factory, G_TYPE_OBJECT);
 
-#define GET_PRIVATE(obj)    (G_TYPE_INSTANCE_GET_PRIVATE((obj), CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, ChamplainMapSourceFactoryPrivate))
+#define GET_PRIVATE(obj) \
+  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, ChamplainMapSourceFactoryPrivate))
 
 struct _ChamplainMapSourceFactoryPrivate
 {
   GSList *registered_sources;
 };
 
-static ChamplainMapSource * champlain_map_source_new_generic (
-    ChamplainMapSourceDesc *desc, gpointer data);
+static ChamplainMapSource *champlain_map_source_new_generic (
+    ChamplainMapSourceDesc *desc,
+    gpointer data);
 
 #ifdef CHAMPLAIN_HAS_MEMPHIS
-static ChamplainMapSource * champlain_map_source_new_memphis (
-    ChamplainMapSourceDesc *desc, gpointer user_data);
+static ChamplainMapSource *champlain_map_source_new_memphis (
+    ChamplainMapSourceDesc *desc,
+    gpointer user_data);
 #endif
 
-static void
-champlain_map_source_factory_get_property (GObject *object,
-    guint prop_id,
-    G_GNUC_UNUSED GValue *value,
-    GParamSpec *pspec)
-{
-  //ChamplainMapSourceFactory *map_source_factory = CHAMPLAIN_MAP_SOURCE_FACTORY(object);
-  //ChamplainMapSourceFactoryPrivate *priv = map_source_factory->priv;
-
-  switch (prop_id)
-    {
-      default:
-        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
-    }
-}
-
-static void
-champlain_map_source_factory_set_property (GObject *object,
-    guint prop_id,
-    G_GNUC_UNUSED const GValue *value,
-    GParamSpec *pspec)
-{
-  //ChamplainMapSourceFactory *map_source_factory = CHAMPLAIN_MAP_SOURCE_FACTORY(object);
-  //ChamplainMapSourceFactoryPrivate *priv = map_source_factory->priv;
-
-  switch (prop_id)
-    {
-      default:
-        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
-    }
-}
 
 static void
 champlain_map_source_factory_finalize (GObject *object)
@@ -128,6 +103,7 @@ champlain_map_source_factory_finalize (GObject *object)
   G_OBJECT_CLASS (champlain_map_source_factory_parent_class)->finalize (object);
 }
 
+
 static GObject *
 champlain_map_source_factory_constructor (GType type,
     guint n_construct_params,
@@ -138,7 +114,7 @@ champlain_map_source_factory_constructor (GType type,
   if (instance == NULL)
     {
       retval = G_OBJECT_CLASS (champlain_map_source_factory_parent_class)->constructor
-          (type, n_construct_params, construct_params);
+                 (type, n_construct_params, construct_params);
 
       instance = CHAMPLAIN_MAP_SOURCE_FACTORY (retval);
       g_object_add_weak_pointer (retval, (gpointer *) &instance);
@@ -151,6 +127,7 @@ champlain_map_source_factory_constructor (GType type,
   return retval;
 }
 
+
 static void
 champlain_map_source_factory_class_init (ChamplainMapSourceFactoryClass *klass)
 {
@@ -160,133 +137,132 @@ champlain_map_source_factory_class_init (ChamplainMapSourceFactoryClass *klass)
 
   object_class->constructor = champlain_map_source_factory_constructor;
   object_class->finalize = champlain_map_source_factory_finalize;
-  object_class->get_property = champlain_map_source_factory_get_property;
-  object_class->set_property = champlain_map_source_factory_set_property;
 }
 
+
 static
 ChamplainMapSourceDesc OSM_MAPNIK_DESC =
-  {
-    CHAMPLAIN_MAP_SOURCE_OSM_MAPNIK,
-    "OpenStreetMap Mapnik",
-    "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
-    "http://creativecommons.org/licenses/by-sa/2.0/",
-    0,
-    18,
-    CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-    champlain_map_source_new_generic,
-    "http://tile.openstreetmap.org/#Z#/#X#/#Y#.png",
-    NULL
-  };
+{
+  CHAMPLAIN_MAP_SOURCE_OSM_MAPNIK,
+  "OpenStreetMap Mapnik",
+  "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
+  "http://creativecommons.org/licenses/by-sa/2.0/",
+  0,
+  18,
+  CHAMPLAIN_MAP_PROJECTION_MERCATOR,
+  champlain_map_source_new_generic,
+  "http://tile.openstreetmap.org/#Z#/#X#/#Y#.png",
+  NULL
+};
 
 static
 ChamplainMapSourceDesc OSM_OSMARENDER_DESC =
-  {
-    CHAMPLAIN_MAP_SOURCE_OSM_OSMARENDER,
-    "OpenStreetMap Osmarender",
-    "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
-    "http://creativecommons.org/licenses/by-sa/2.0/",
-    0,
-    17,
-    CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-    champlain_map_source_new_generic,
-    "http://tah.openstreetmap.org/Tiles/tile/#Z#/#X#/#Y#.png",
-    NULL
-  };
+{
+  CHAMPLAIN_MAP_SOURCE_OSM_OSMARENDER,
+  "OpenStreetMap Osmarender",
+  "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
+  "http://creativecommons.org/licenses/by-sa/2.0/",
+  0,
+  17,
+  CHAMPLAIN_MAP_PROJECTION_MERCATOR,
+  champlain_map_source_new_generic,
+  "http://tah.openstreetmap.org/Tiles/tile/#Z#/#X#/#Y#.png",
+  NULL
+};
 
 static
 ChamplainMapSourceDesc OSM_CYCLEMAP_DESC =
-  {
-    CHAMPLAIN_MAP_SOURCE_OSM_CYCLE_MAP,
-    "OpenStreetMap Cycle Map",
-    "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
-    "http://creativecommons.org/licenses/by-sa/2.0/",
-    0,
-    18,
-    CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-    champlain_map_source_new_generic,
-    "http://andy.sandbox.cloudmade.com/tiles/cycle/#Z#/#X#/#Y#.png",
-    NULL
-  };
+{
+  CHAMPLAIN_MAP_SOURCE_OSM_CYCLE_MAP,
+  "OpenStreetMap Cycle Map",
+  "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
+  "http://creativecommons.org/licenses/by-sa/2.0/",
+  0,
+  18,
+  CHAMPLAIN_MAP_PROJECTION_MERCATOR,
+  champlain_map_source_new_generic,
+  "http://andy.sandbox.cloudmade.com/tiles/cycle/#Z#/#X#/#Y#.png",
+  NULL
+};
 
 static
 ChamplainMapSourceDesc OSM_TRANSPORTMAP_DESC =
-  {
-    CHAMPLAIN_MAP_SOURCE_OSM_TRANSPORT_MAP,
-    "OpenStreetMap Transport Map",
-    "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
-    "http://creativecommons.org/licenses/by-sa/2.0/",
-    0,
-    18,
-    CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-    champlain_map_source_new_generic,
-    "http://tile.xn--pnvkarte-m4a.de/tilegen/#Z#/#X#/#Y#.png",
-    NULL
-  };
+{
+  CHAMPLAIN_MAP_SOURCE_OSM_TRANSPORT_MAP,
+  "OpenStreetMap Transport Map",
+  "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
+  "http://creativecommons.org/licenses/by-sa/2.0/",
+  0,
+  18,
+  CHAMPLAIN_MAP_PROJECTION_MERCATOR,
+  champlain_map_source_new_generic,
+  "http://tile.xn--pnvkarte-m4a.de/tilegen/#Z#/#X#/#Y#.png",
+  NULL
+};
 
 #if 0
 /* Disabling until OpenArealMap works again */
 static
 ChamplainMapSourceDesc OAM_DESC =
-  {
-    CHAMPLAIN_MAP_SOURCE_OAM,
-    "OpenAerialMap",
-    "(CC) BY 3.0 OpenAerialMap contributors",
-    "http://creativecommons.org/licenses/by/3.0/",
-    0,
-    17,
-    CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-    champlain_map_source_new_generic,
-    "http://tile.openaerialmap.org/tiles/1.0.0/openaerialmap-900913/#Z#/#X#/#Y#.jpg",
-    NULL
-  };
+{
+  CHAMPLAIN_MAP_SOURCE_OAM,
+  "OpenAerialMap",
+  "(CC) BY 3.0 OpenAerialMap contributors",
+  "http://creativecommons.org/licenses/by/3.0/",
+  0,
+  17,
+  CHAMPLAIN_MAP_PROJECTION_MERCATOR,
+  champlain_map_source_new_generic,
+  "http://tile.openaerialmap.org/tiles/1.0.0/openaerialmap-900913/#Z#/#X#/#Y#.jpg",
+  NULL
+};
 #endif
 
 static
 ChamplainMapSourceDesc MFF_RELIEF_DESC =
-  {
-    CHAMPLAIN_MAP_SOURCE_MFF_RELIEF,
-    "Maps for Free Relief",
-    "Map data available under GNU Free Documentation license, Version 1.2 or later",
-    "http://www.gnu.org/copyleft/fdl.html",
-    0,
-    11,
-    CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-    champlain_map_source_new_generic,
-    "http://maps-for-free.com/layer/relief/z#Z#/row#Y#/#Z#_#X#-#Y#.jpg",
-    NULL
-  };
+{
+  CHAMPLAIN_MAP_SOURCE_MFF_RELIEF,
+  "Maps for Free Relief",
+  "Map data available under GNU Free Documentation license, Version 1.2 or later",
+  "http://www.gnu.org/copyleft/fdl.html",
+  0,
+  11,
+  CHAMPLAIN_MAP_PROJECTION_MERCATOR,
+  champlain_map_source_new_generic,
+  "http://maps-for-free.com/layer/relief/z#Z#/row#Y#/#Z#_#X#-#Y#.jpg",
+  NULL
+};
 
 #ifdef CHAMPLAIN_HAS_MEMPHIS
 static
 ChamplainMapSourceDesc MEMPHIS_LOCAL_DESC =
-  {
-    CHAMPLAIN_MAP_SOURCE_MEMPHIS_LOCAL,
-    "OpenStreetMap Memphis Local Map",
-    "(CC) BY 2.0 OpenStreetMap contributors",
-    "http://creativecommons.org/licenses/by/2.0/",
-    12,
-    18,
-    CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-    champlain_map_source_new_memphis,
-    "",
-    NULL
-  };
+{
+  CHAMPLAIN_MAP_SOURCE_MEMPHIS_LOCAL,
+  "OpenStreetMap Memphis Local Map",
+  "(CC) BY 2.0 OpenStreetMap contributors",
+  "http://creativecommons.org/licenses/by/2.0/",
+  12,
+  18,
+  CHAMPLAIN_MAP_PROJECTION_MERCATOR,
+  champlain_map_source_new_memphis,
+  "",
+  NULL
+};
 
 static
 ChamplainMapSourceDesc MEMPHIS_NETWORK_DESC =
-  {
-    CHAMPLAIN_MAP_SOURCE_MEMPHIS_NETWORK,
-    "OpenStreetMap Memphis Network Map",
-    "(CC) BY 2.0 OpenStreetMap contributors",
-    "http://creativecommons.org/licenses/by/2.0/",
-    12,
-    18,
-    CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-    champlain_map_source_new_memphis,
-    "",
-    NULL
-  };
+{
+  CHAMPLAIN_MAP_SOURCE_MEMPHIS_NETWORK,
+  "OpenStreetMap Memphis Network Map",
+  "(CC) BY 2.0 OpenStreetMap contributors",
+  "http://creativecommons.org/licenses/by/2.0/",
+  12,
+  18,
+  CHAMPLAIN_MAP_PROJECTION_MERCATOR,
+  champlain_map_source_new_memphis,
+  "",
+  NULL
+};
 #endif
 
 static void
@@ -320,6 +296,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
 #endif
 }
 
+
 /**
  * champlain_map_source_factory_dup_default:
  *
@@ -336,6 +313,7 @@ champlain_map_source_factory_dup_default (void)
   return g_object_new (CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, NULL);
 }
 
+
 /**
  * champlain_map_source_factory_dup_list:
  * @factory: the Factory
@@ -353,6 +331,7 @@ champlain_map_source_factory_dup_list (ChamplainMapSourceFactory *factory)
   return g_slist_copy (factory->priv->registered_sources);
 }
 
+
 /**
  * champlain_map_source_factory_create:
  * @factory: the Factory
@@ -385,6 +364,7 @@ champlain_map_source_factory_create (ChamplainMapSourceFactory *factory,
   return NULL;
 }
 
+
 /**
  * champlain_map_source_factory_create_cached_source:
  * @factory: the Factory
@@ -398,7 +378,8 @@ champlain_map_source_factory_create (ChamplainMapSourceFactory *factory,
  *
  * Since: 0.6
  */
-ChamplainMapSource * champlain_map_source_factory_create_cached_source (ChamplainMapSourceFactory *factory,
+ChamplainMapSource *
+champlain_map_source_factory_create_cached_source (ChamplainMapSourceFactory *factory,
     const gchar *id)
 {
   ChamplainMapSourceChain *source_chain;
@@ -406,22 +387,39 @@ ChamplainMapSource * champlain_map_source_factory_create_cached_source (Champlai
   ChamplainMapSource *error_source;
   ChamplainMapSource *file_cache;
   guint tile_size;
+  ChamplainRenderer *renderer;
 
   tile_source = champlain_map_source_factory_create (factory, id);
 
   tile_size = champlain_map_source_get_tile_size (tile_source);
-  error_source = CHAMPLAIN_MAP_SOURCE(champlain_error_tile_source_new_full (tile_size));
+  error_source = champlain_map_source_factory_create_error_source (factory, tile_size);
 
-  file_cache = CHAMPLAIN_MAP_SOURCE(champlain_file_cache_new ());
+  renderer = CHAMPLAIN_RENDERER (champlain_image_renderer_new ());
+  file_cache = CHAMPLAIN_MAP_SOURCE (champlain_file_cache_new_full (100000000, NULL, renderer));
 
   source_chain = champlain_map_source_chain_new ();
   champlain_map_source_chain_push (source_chain, error_source);
   champlain_map_source_chain_push (source_chain, tile_source);
   champlain_map_source_chain_push (source_chain, file_cache);
 
-  return CHAMPLAIN_MAP_SOURCE(source_chain);
+  return CHAMPLAIN_MAP_SOURCE (source_chain);
 }
 
+
+ChamplainMapSource *
+champlain_map_source_factory_create_error_source (ChamplainMapSourceFactory *factory,
+    guint tile_size)
+{
+  ChamplainMapSource *null_source;
+  ChamplainRenderer *renderer;
+
+  renderer = CHAMPLAIN_RENDERER (champlain_error_tile_renderer_new (tile_size));
+  null_source = CHAMPLAIN_MAP_SOURCE (champlain_null_tile_source_new_full (renderer));
+
+  return null_source;
+}
+
+
 /**
  * champlain_map_source_factory_register:
  * @factory: A #ChamplainMapSourceFactory
@@ -445,7 +443,6 @@ champlain_map_source_factory_register (ChamplainMapSourceFactory *factory,
     ChamplainMapSourceConstructor constructor,
     gpointer data)
 {
-
   /* FIXME: check for existing factory with that name? */
   desc->constructor = constructor;
   desc->data = data;
@@ -453,54 +450,69 @@ champlain_map_source_factory_register (ChamplainMapSourceFactory *factory,
   return TRUE;
 }
 
+
 static ChamplainMapSource *
 champlain_map_source_new_generic (
     ChamplainMapSourceDesc *desc, G_GNUC_UNUSED gpointer user_data)
 {
-  return CHAMPLAIN_MAP_SOURCE (champlain_network_tile_source_new_full (
-      desc->id,
-      desc->name,
-      desc->license,
-      desc->license_uri,
-      desc->min_zoom_level,
-      desc->max_zoom_level,
-      256,
-      desc->projection,
-      desc->uri_format));
+  ChamplainMapSource *map_source;
+  ChamplainRenderer *renderer;
+
+  renderer = CHAMPLAIN_RENDERER (champlain_image_renderer_new ());
+  map_source = CHAMPLAIN_MAP_SOURCE (champlain_network_tile_source_new_full (
+          desc->id,
+          desc->name,
+          desc->license,
+          desc->license_uri,
+          desc->min_zoom_level,
+          desc->max_zoom_level,
+          256,
+          desc->projection,
+          desc->uri_format,
+          renderer));
+
+  return map_source;
 }
 
+
 #ifdef CHAMPLAIN_HAS_MEMPHIS
 static ChamplainMapSource *
 champlain_map_source_new_memphis (ChamplainMapSourceDesc *desc,
     G_GNUC_UNUSED gpointer user_data)
 {
-  ChamplainMapDataSource *map_data_source;
+  ChamplainMapSource *map_source;
+  ChamplainRenderer *renderer;
 
+  renderer = CHAMPLAIN_RENDERER (champlain_memphis_renderer_new_full (256));
   if (g_strcmp0 (desc->id, CHAMPLAIN_MAP_SOURCE_MEMPHIS_LOCAL) == 0)
     {
-      map_data_source = CHAMPLAIN_MAP_DATA_SOURCE (champlain_local_map_data_source_new ());
-
-      /* Abuse the uri_format field to store an initial data path (optional) */
-      if (desc->uri_format && g_strcmp0 (desc->uri_format, "") != 0)
-        champlain_local_map_data_source_load_map_data (
-            CHAMPLAIN_LOCAL_MAP_DATA_SOURCE (map_data_source),
-            desc->uri_format);
+      map_source = CHAMPLAIN_MAP_SOURCE (champlain_file_tile_source_new_full (
+              desc->id,
+              desc->name,
+              desc->license,
+              desc->license_uri,
+              desc->min_zoom_level,
+              desc->max_zoom_level,
+              256,
+              desc->projection,
+              renderer));
     }
-  else if (g_strcmp0 (desc->id, CHAMPLAIN_MAP_SOURCE_MEMPHIS_NETWORK) == 0)
-      map_data_source = CHAMPLAIN_MAP_DATA_SOURCE (champlain_network_map_data_source_new ());
   else
-    return NULL;
+    {
+      map_source = CHAMPLAIN_MAP_SOURCE (champlain_network_bbox_tile_source_new_full (
+              desc->id,
+              desc->name,
+              desc->license,
+              desc->license_uri,
+              desc->min_zoom_level,
+              desc->max_zoom_level,
+              256,
+              desc->projection,
+              renderer));
+    }
 
-  return CHAMPLAIN_MAP_SOURCE (champlain_memphis_tile_source_new_full (
-      desc->id,
-      desc->name,
-      desc->license,
-      desc->license_uri,
-      desc->min_zoom_level,
-      desc->max_zoom_level,
-      256,
-      desc->projection,
-      map_data_source));
+  return map_source;
 }
-#endif
 
+
+#endif
