@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2008-2009 Pierre-Luc Beaudoin <pierre-luc@pierlux.com>
+ * Copyright (C) 2010 Jiri Techet <techet@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -52,7 +53,17 @@ enum
   PROP_FADE_IN
 };
 
-struct _ChamplainTilePrivate {
+enum
+{
+  /* normal signals */
+  RENDER_COMPLETE,
+  LAST_SIGNAL
+};
+
+static guint champlain_tile_signals[LAST_SIGNAL] = { 0, };
+
+struct _ChamplainTilePrivate
+{
   gint x; /* The x position on the map (in pixels) */
   gint y; /* The y position on the map (in pixels) */
   gint size; /* The tile's width and height (only support square tiles */
@@ -63,7 +74,7 @@ struct _ChamplainTilePrivate {
   gboolean fade_in;
 
   GTimeVal *modified_time; /* The last modified time of the cache */
-  gchar* etag; /* The HTTP ETag sent by the server */
+  gchar *etag; /* The HTTP ETag sent by the server */
 };
 
 static void
@@ -73,37 +84,47 @@ champlain_tile_get_property (GObject *object,
     GParamSpec *pspec)
 {
   ChamplainTile *self = CHAMPLAIN_TILE (object);
+
   switch (property_id)
     {
-      case PROP_X:
-        g_value_set_int (value, champlain_tile_get_x (self));
-        break;
-      case PROP_Y:
-        g_value_set_int (value, champlain_tile_get_y (self));
-        break;
-      case PROP_ZOOM_LEVEL:
-        g_value_set_int (value, champlain_tile_get_zoom_level (self));
-        break;
-      case PROP_SIZE:
-        g_value_set_uint (value, champlain_tile_get_size (self));
-        break;
-      case PROP_STATE:
-        g_value_set_enum (value, champlain_tile_get_state (self));
-        break;
-      case PROP_CONTENT:
-        g_value_set_object (value, champlain_tile_get_content (self));
-        break;
-      case PROP_ETAG:
-        g_value_set_string (value, champlain_tile_get_etag (self));
-        break;
-      case PROP_FADE_IN:
-        g_value_set_boolean (value, champlain_tile_get_fade_in (self));
-        break;
-      default:
-        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    case PROP_X:
+      g_value_set_int (value, champlain_tile_get_x (self));
+      break;
+
+    case PROP_Y:
+      g_value_set_int (value, champlain_tile_get_y (self));
+      break;
+
+    case PROP_ZOOM_LEVEL:
+      g_value_set_int (value, champlain_tile_get_zoom_level (self));
+      break;
+
+    case PROP_SIZE:
+      g_value_set_uint (value, champlain_tile_get_size (self));
+      break;
+
+    case PROP_STATE:
+      g_value_set_enum (value, champlain_tile_get_state (self));
+      break;
+
+    case PROP_CONTENT:
+      g_value_set_object (value, champlain_tile_get_content (self));
+      break;
+
+    case PROP_ETAG:
+      g_value_set_string (value, champlain_tile_get_etag (self));
+      break;
+
+    case PROP_FADE_IN:
+      g_value_set_boolean (value, champlain_tile_get_fade_in (self));
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
     }
 }
 
+
 static void
 champlain_tile_set_property (GObject *object,
     guint property_id,
@@ -111,37 +132,47 @@ champlain_tile_set_property (GObject *object,
     GParamSpec *pspec)
 {
   ChamplainTile *self = CHAMPLAIN_TILE (object);
+
   switch (property_id)
     {
-      case PROP_X:
-        champlain_tile_set_x (self, g_value_get_int (value));
-        break;
-      case PROP_Y:
-        champlain_tile_set_y (self, g_value_get_int (value));
-        break;
-      case PROP_ZOOM_LEVEL:
-        champlain_tile_set_zoom_level (self, g_value_get_int (value));
-        break;
-      case PROP_SIZE:
-        champlain_tile_set_size (self, g_value_get_uint (value));
-        break;
-      case PROP_STATE:
-        champlain_tile_set_state (self, g_value_get_enum (value));
-        break;
-      case PROP_CONTENT:
-        champlain_tile_set_content (self, g_value_get_object (value));
-        break;
-      case PROP_ETAG:
-        champlain_tile_set_etag (self, g_value_get_string (value));
-        break;
-      case PROP_FADE_IN:
-        champlain_tile_set_fade_in (self, g_value_get_boolean (value));
-        break;
-      default:
-        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    case PROP_X:
+      champlain_tile_set_x (self, g_value_get_int (value));
+      break;
+
+    case PROP_Y:
+      champlain_tile_set_y (self, g_value_get_int (value));
+      break;
+
+    case PROP_ZOOM_LEVEL:
+      champlain_tile_set_zoom_level (self, g_value_get_int (value));
+      break;
+
+    case PROP_SIZE:
+      champlain_tile_set_size (self, g_value_get_uint (value));
+      break;
+
+    case PROP_STATE:
+      champlain_tile_set_state (self, g_value_get_enum (value));
+      break;
+
+    case PROP_CONTENT:
+      champlain_tile_set_content (self, g_value_get_object (value));
+      break;
+
+    case PROP_ETAG:
+      champlain_tile_set_etag (self, g_value_get_string (value));
+      break;
+
+    case PROP_FADE_IN:
+      champlain_tile_set_fade_in (self, g_value_get_boolean (value));
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
     }
 }
 
+
 static void
 champlain_tile_dispose (GObject *object)
 {
@@ -156,6 +187,7 @@ champlain_tile_dispose (GObject *object)
   G_OBJECT_CLASS (champlain_tile_parent_class)->dispose (object);
 }
 
+
 static void
 champlain_tile_finalize (GObject *object)
 {
@@ -167,6 +199,7 @@ champlain_tile_finalize (GObject *object)
   G_OBJECT_CLASS (champlain_tile_parent_class)->finalize (object);
 }
 
+
 static void
 champlain_tile_class_init (ChamplainTileClass *klass)
 {
@@ -180,12 +213,12 @@ champlain_tile_class_init (ChamplainTileClass *klass)
   object_class->finalize = champlain_tile_finalize;
 
   /**
-  * ChamplainTile:x:
-  *
-  * The x position of the tile
-  *
-  * Since: 0.4
-  */
+   * ChamplainTile:x:
+   *
+   * The x position of the tile
+   *
+   * Since: 0.4
+   */
   g_object_class_install_property (object_class,
       PROP_X,
       g_param_spec_int ("x",
@@ -197,12 +230,12 @@ champlain_tile_class_init (ChamplainTileClass *klass)
           G_PARAM_READWRITE));
 
   /**
-  * ChamplainTile:y:
-  *
-  * The y position of the tile
-  *
-  * Since: 0.4
-  */
+   * ChamplainTile:y:
+   *
+   * The y position of the tile
+   *
+   * Since: 0.4
+   */
   g_object_class_install_property (object_class,
       PROP_Y,
       g_param_spec_int ("y",
@@ -214,12 +247,12 @@ champlain_tile_class_init (ChamplainTileClass *klass)
           G_PARAM_READWRITE));
 
   /**
-  * ChamplainTile:zoom-level:
-  *
-  * The zoom level of the tile
-  *
-  * Since: 0.4
-  */
+   * ChamplainTile:zoom-level:
+   *
+   * The zoom level of the tile
+   *
+   * Since: 0.4
+   */
   g_object_class_install_property (object_class,
       PROP_ZOOM_LEVEL,
       g_param_spec_int ("zoom-level",
@@ -231,12 +264,12 @@ champlain_tile_class_init (ChamplainTileClass *klass)
           G_PARAM_READWRITE));
 
   /**
-  * ChamplainTile:size:
-  *
-  * The size of the tile in pixels
-  *
-  * Since: 0.4
-  */
+   * ChamplainTile:size:
+   *
+   * The size of the tile in pixels
+   *
+   * Since: 0.4
+   */
   g_object_class_install_property (object_class,
       PROP_SIZE,
       g_param_spec_uint ("size",
@@ -248,12 +281,12 @@ champlain_tile_class_init (ChamplainTileClass *klass)
           G_PARAM_READWRITE));
 
   /**
-  * ChamplainTile:state:
-  *
-  * The state of the tile
-  *
-  * Since: 0.4
-  */
+   * ChamplainTile:state:
+   *
+   * The state of the tile
+   *
+   * Since: 0.4
+   */
   g_object_class_install_property (object_class,
       PROP_STATE,
       g_param_spec_enum ("state",
@@ -264,13 +297,13 @@ champlain_tile_class_init (ChamplainTileClass *klass)
           G_PARAM_READWRITE));
 
   /**
-  * ChamplainTile:content:
-  *
-  * The #ClutterActor with the specific image content.  When changing this
-  * property, the new actor will be faded in.
-  *
-  * Since: 0.4
-  */
+   * ChamplainTile:content:
+   *
+   * The #ClutterActor with the specific image content.  When changing this
+   * property, the new actor will be faded in.
+   *
+   * Since: 0.4
+   */
   g_object_class_install_property (object_class,
       PROP_CONTENT,
       g_param_spec_object ("content",
@@ -280,14 +313,14 @@ champlain_tile_class_init (ChamplainTileClass *klass)
           G_PARAM_READWRITE));
 
   /**
-  * ChamplainTile:etag:
-  *
-  * The tile's ETag. This information is sent by some web servers as a mean
-  * to identify if a tile has changed.  This information is saved in the cache
-  * and sent in GET queries.
-  *
-  * Since: 0.4
-  */
+   * ChamplainTile:etag:
+   *
+   * The tile's ETag. This information is sent by some web servers as a mean
+   * to identify if a tile has changed.  This information is saved in the cache
+   * and sent in GET queries.
+   *
+   * Since: 0.4
+   */
   g_object_class_install_property (object_class,
       PROP_ETAG,
       g_param_spec_string ("etag",
@@ -297,12 +330,12 @@ champlain_tile_class_init (ChamplainTileClass *klass)
           G_PARAM_READWRITE));
 
   /**
-  * ChamplainTile:fade-in:
-  *
-  * Specifies whether the tile should fade in when loading
-  *
-  * Since: 0.6
-  */
+   * ChamplainTile:fade-in:
+   *
+   * Specifies whether the tile should fade in when loading
+   *
+   * Since: 0.6
+   */
   g_object_class_install_property (object_class,
       PROP_FADE_IN,
       g_param_spec_boolean ("fade-in",
@@ -310,8 +343,15 @@ champlain_tile_class_init (ChamplainTileClass *klass)
           "Tile should fade in",
           FALSE,
           G_PARAM_READWRITE));
+
+  champlain_tile_signals[RENDER_COMPLETE] =
+    g_signal_new ("render-complete", G_OBJECT_CLASS_TYPE (object_class),
+        G_SIGNAL_RUN_LAST, 0, NULL, NULL,
+        g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE,
+        1, G_TYPE_POINTER);
 }
 
+
 static void
 champlain_tile_init (ChamplainTile *self)
 {
@@ -331,6 +371,7 @@ champlain_tile_init (ChamplainTile *self)
   priv->content_actor = NULL;
 }
 
+
 /**
  * champlain_tile_new:
  *
@@ -340,12 +381,13 @@ champlain_tile_init (ChamplainTile *self)
  *
  * Since: 0.4
  */
-ChamplainTile*
+ChamplainTile *
 champlain_tile_new (void)
 {
   return g_object_new (CHAMPLAIN_TYPE_TILE, NULL);
 }
 
+
 /**
  * champlain_tile_get_x:
  * @self: the #ChamplainTile
@@ -364,6 +406,7 @@ champlain_tile_get_x (ChamplainTile *self)
   return self->priv->x;
 }
 
+
 /**
  * champlain_tile_get_y:
  * @self: the #ChamplainTile
@@ -382,6 +425,7 @@ champlain_tile_get_y (ChamplainTile *self)
   return self->priv->y;
 }
 
+
 /**
  * champlain_tile_get_zoom_level:
  * @self: the #ChamplainTile
@@ -400,6 +444,7 @@ champlain_tile_get_zoom_level (ChamplainTile *self)
   return self->priv->zoom_level;
 }
 
+
 /**
  * champlain_tile_get_size:
  * @self: the #ChamplainTile
@@ -418,6 +463,7 @@ champlain_tile_get_size (ChamplainTile *self)
   return self->priv->size;
 }
 
+
 /**
  * champlain_tile_get_state:
  * @self: the #ChamplainTile
@@ -436,6 +482,7 @@ champlain_tile_get_state (ChamplainTile *self)
   return self->priv->state;
 }
 
+
 /**
  * champlain_tile_set_x:
  * @self: the #ChamplainTile
@@ -456,6 +503,7 @@ champlain_tile_set_x (ChamplainTile *self,
   g_object_notify (G_OBJECT (self), "x");
 }
 
+
 /**
  * champlain_tile_set_y:
  * @self: the #ChamplainTile
@@ -476,6 +524,7 @@ champlain_tile_set_y (ChamplainTile *self,
   g_object_notify (G_OBJECT (self), "y");
 }
 
+
 /**
  * champlain_tile_set_zoom_level:
  * @self: the #ChamplainTile
@@ -496,6 +545,7 @@ champlain_tile_set_zoom_level (ChamplainTile *self,
   g_object_notify (G_OBJECT (self), "zoom-level");
 }
 
+
 /**
  * champlain_tile_set_size:
  * @self: the #ChamplainTile
@@ -516,6 +566,7 @@ champlain_tile_set_size (ChamplainTile *self,
   g_object_notify (G_OBJECT (self), "size");
 }
 
+
 /**
  * champlain_tile_set_state:
  * @self: the #ChamplainTile
@@ -536,34 +587,11 @@ champlain_tile_set_state (ChamplainTile *self,
   if (state == priv->state)
     return;
 
-  if (state == CHAMPLAIN_STATE_DONE && priv->content_actor &&
-      clutter_actor_get_parent (priv->content_actor) != CLUTTER_ACTOR (self))
-    {
-      clutter_actor_set_opacity (priv->content_actor, 0);
-      clutter_container_add_actor (CLUTTER_CONTAINER (self), priv->content_actor);
-
-      if (priv->fade_in)
-        {
-          clutter_actor_animate (priv->content_actor,
-              CLUTTER_EASE_IN_CUBIC,
-              500,
-              "opacity", 255,
-              NULL);
-        }
-      else
-        {
-          clutter_actor_animate (priv->content_actor,
-              CLUTTER_LINEAR,
-              150,
-              "opacity", 255,
-              NULL);
-        }
-    }
-
   priv->state = state;
   g_object_notify (G_OBJECT (self), "state");
 }
 
+
 /**
  * champlain_tile_new_full:
  * @x: the x position
@@ -577,7 +605,7 @@ champlain_tile_set_state (ChamplainTile *self,
  *
  * Since: 0.4
  */
-ChamplainTile*
+ChamplainTile *
 champlain_tile_new_full (gint x,
     gint y,
     guint size,
@@ -587,6 +615,7 @@ champlain_tile_new_full (gint x,
       zoom_level, "size", size, NULL);
 }
 
+
 /**
  * champlain_tile_get_modified_time:
  * @self: the #ChamplainTile
@@ -605,6 +634,7 @@ champlain_tile_get_modified_time (ChamplainTile *self)
   return self->priv->modified_time;
 }
 
+
 /**
  * champlain_tile_set_modified_time:
  * @self: the #ChamplainTile
@@ -624,9 +654,10 @@ champlain_tile_set_modified_time (ChamplainTile *self,
   ChamplainTilePrivate *priv = self->priv;
 
   g_free (priv->modified_time);
-  priv->modified_time = g_memdup(time_, sizeof (GTimeVal));
+  priv->modified_time = g_memdup (time_, sizeof (GTimeVal));
 }
 
+
 /**
  * champlain_tile_get_etag:
  * @self: the #ChamplainTile
@@ -645,6 +676,7 @@ champlain_tile_get_etag (ChamplainTile *self)
   return self->priv->etag;
 }
 
+
 /**
  * champlain_tile_set_etag:
  * @self: the #ChamplainTile
@@ -667,6 +699,7 @@ champlain_tile_set_etag (ChamplainTile *self,
   g_object_notify (G_OBJECT (self), "etag");
 }
 
+
 /**
  * champlain_tile_set_content:
  * @self: the #ChamplainTile
@@ -693,6 +726,53 @@ champlain_tile_set_content (ChamplainTile *self,
   g_object_notify (G_OBJECT (self), "content");
 }
 
+
+static void
+fade_in_completed (G_GNUC_UNUSED ClutterAnimation *animation, ChamplainTile *self)
+{
+  if (clutter_group_get_n_children (CLUTTER_GROUP (self)) > 1)
+    clutter_actor_destroy (clutter_group_get_nth_child (CLUTTER_GROUP (self), 0));
+}
+
+
+void
+champlain_tile_display_content (ChamplainTile *self)
+{
+  g_return_if_fail (CHAMPLAIN_TILE (self));
+
+  ChamplainTilePrivate *priv = self->priv;
+  ClutterAnimation *animation;
+
+  if (!priv->content_actor)
+    return;
+
+  clutter_actor_set_opacity (priv->content_actor, 0);
+  clutter_container_add_actor (CLUTTER_CONTAINER (self), priv->content_actor);
+
+  if (priv->fade_in)
+    {
+      animation = clutter_actor_animate (priv->content_actor,
+          CLUTTER_EASE_IN_CUBIC,
+          500,
+          "opacity", 255,
+          NULL);
+    }
+  else
+    {
+      animation = clutter_actor_animate (priv->content_actor,
+          CLUTTER_LINEAR,
+          150,
+          "opacity", 255,
+          NULL);
+    }
+
+  g_signal_connect (animation, "completed", G_CALLBACK (fade_in_completed), self);
+
+  g_object_unref (priv->content_actor);
+  priv->content_actor = NULL;
+}
+
+
 /**
  * champlain_tile_get_content:
  * @self: the #ChamplainTile
@@ -712,6 +792,7 @@ champlain_tile_get_content (ChamplainTile *self)
   return self->priv->content_actor;
 }
 
+
 /**
  * champlain_tile_get_fade_in:
  * @self: the #ChamplainTile
@@ -730,6 +811,7 @@ champlain_tile_get_fade_in (ChamplainTile *self)
   return self->priv->fade_in;
 }
 
+
 /**
  * champlain_tile_set_fade_in:
  * @self: the #ChamplainTile
